@@ -1,4 +1,4 @@
-package Algorithm::CheckDigits::M10_004;
+package Algorithm::CheckDigits::M10_001;
 
 use 5.006;
 use strict;
@@ -7,6 +7,37 @@ use integer;
 
 our @ISA = qw(Algorithm::CheckDigits);
 
+my %prefix = (
+	'amex'		=> [ '34', '37' ],
+	'bahncard'	=> [ '70' ],
+	'diners'	=> [ '30[0-5]', '36', '38' ],
+	'discover'	=> [ '6011' ],
+	'enroute'	=> [ '2014', '2149' ],
+	'jcb'		=> [ '1800', '2131', '3088' ],
+	'mastercard'	=> [ '5[1-5]' ],
+	'miles&more'	=> [ '99', '22' ],
+	'visa'		=> [ '4' ],
+);
+
+my %ctable = (
+	'A' => 10, 'B' => 11, 'C' => 12, 'D' => 13, 'E' => 14,
+	'F' => 15, 'G' => 16, 'H' => 17, 'I' => 18, 'J' => 19,
+	'K' => 20, 'L' => 21, 'M' => 22, 'N' => 23, 'O' => 24,
+	'P' => 25, 'Q' => 26, 'R' => 27, 'S' => 28, 'T' => 29,
+	'U' => 30, 'V' => 31, 'W' => 32, 'X' => 33, 'Y' => 34,
+	'Z' => 35,
+);
+
+# Aliases
+$prefix{'eurocard'} = $prefix{'mastercard'};
+
+# omit prefixes doesn't work with the test numbers
+my %omitprefix = (
+	'jcb'		=> 0,
+	'enroute'	=> 0,
+	'discover'	=> 0,
+);
+
 sub new {
 	my $proto = shift;
 	my $type  = shift;
@@ -18,32 +49,32 @@ sub new {
 
 sub is_valid {
 	my ($self,$number) = @_;
-	if ($number =~ /^([0-9 ]*)([0-9])$/) {
-		return $2 == $self->_compute_checkdigit($1);
+	if ($number =~ /^([0-9A-Z ]*)([0-9])$/i) {
+		return $2 == $self->_compute_checkdigit(uc($1));
 	}
 	return ''
 } # is_valid()
 
 sub complete {
 	my ($self,$number) = @_;
-	if ($number =~ /^[0-9 ]*$/) {
-		return  $number . $self->_compute_checkdigit($number);
+	if ($number =~ /^[0-9A-Z ]*$/i) {
+		return  $number .  $self->_compute_checkdigit(uc($number));
 	}
 	return '';
 } # complete()
 
 sub basenumber {
 	my ($self,$number) = @_;
-	if ($number =~ /^([0-9 ]*)([0-9])$/) {
-		return $1 if ($2 == $self->_compute_checkdigit($1));
+	if ($number =~ /^([0-9A-Z ]*)([0-9])$/i) {
+		return $1 if ($2 == $self->_compute_checkdigit(uc($1)));
 	}
 	return '';
 } # basenumber()
 
 sub checkdigit {
 	my ($self,$number) = @_;
-	if ($number =~ /^([0-9 ]*)([0-9])$/) {
-		return $2 if ($2 == $self->_compute_checkdigit($1));
+	if ($number =~ /^([0-9A-Z ]*)([0-9])$/i) {
+		return $2 if ($2 == $self->_compute_checkdigit(uc($1)));
 	}
 	return '';
 } # checkdigit()
@@ -52,13 +83,24 @@ sub _compute_checkdigit {
 	my $self   = shift;
 	my $number = shift;
 	$number =~ s/\s//g;
+	if ($omitprefix{$self->{type}}) {
+		my $pf = $prefix{$self->{type}};
+		for my $p (@{$pf}) {
+			if ($number =~ /^$p([0-9]+)$/) {
+				$number = $1;
+				last;
+			}
+		}
+	}
+	$number =~ s/([A-Z])/$ctable{$1}/ge;
 	if ($number =~ /^([0-9]*)$/) {
 		my @digits = split(//,$number);
 		my $even = 1;
 		my $sum  = 0;
 		for (my $i = $#digits;$i >= 0;$i--) {
 			if ($even) {
-				$sum += 3 * $digits[$i];
+				my $tmp = 2 * $digits[$i];
+				$sum += $tmp / 10 + $tmp % 10;
 			} else {
 				$sum += $digits[$i];
 			}
@@ -76,26 +118,30 @@ __END__
 
 =head1 NAME
 
-CheckDigits::M10_004 - compute check digits for 2aus5, EAN, ILN, NVE
+CheckDigits::M10_001 - compute check digits for Bahncard (DE), IMEI,
+IMEISV, ISIN, Miles&More, Payback (DE), Personnummer (SE), Passport
+(BR), Credit Cards, SSN (US), Samordningsnummer (SE), VAT RN (ES), VAT
+RN (IT), VAT RN (SE), International Securities Identifikation Number
+(ISIN)
 
 =head1 SYNOPSIS
 
   use Algorithm::CheckDigits;
 
-  $ean = CheckDigits('ean');
+  $visa = CheckDigits('visa');
 
-  if ($ean->is_valid('7622200004607')) {
+  if ($visa->is_valid('4111 1111 1111 1111')) {
 	# do something
   }
 
-  $cn = $ean->complete('762220000460');
-  # $cn = '7622200004607'
+  $cn = $visa->complete('4111 1111 1111 111');
+  # $cn = '4111 1111 1111 1111'
 
-  $cd = $ean->checkdigit('7622200004607');
+  $cd = $visa->checkdigit('4111 1111 1111 1111');
   # $cd = '7'
 
-  $bn = $ean->basenumber('7622200004607');
-  # $bn = '762220000460'
+  $bn = $visa->basenumber('4111 1111 1111 1111');
+  # $bn = '4111 1111 1111 111'
   
 =head1 DESCRIPTION
 
@@ -105,12 +151,12 @@ CheckDigits::M10_004 - compute check digits for 2aus5, EAN, ILN, NVE
 
 =item 1
 
-Beginning right all numbers are weighted alternatively 1 and 3 (that
+Beginning right all numbers are weighted alternatively 1 and 2 (that
 is the check digit is weighted 1).
 
 =item 2
 
-The sum of all products is computed.
+The total of the digits of all products is computed.
 
 =item 3
 
@@ -118,7 +164,8 @@ The sum of step 3 ist taken modulo 10.
 
 =item 4
 
-The check digit is the difference between 10 and the number from step 3.
+The check digit is the difference between 10 and the number from step
+3.
 
 =back
 
